.. _reference:

=========
Reference
=========
All public objects are documented in these sections.

================== =============================
:ref:`api`         API and PublicAPI classes
:ref:`auth`        OAuth2 class
:ref:`Genius`      Genius class
:ref:`sender`      Request sender
:ref:`types`	   Types
:ref:`utils`       Utility functions
================== =============================

.. toctree::
   :maxdepth: 2
   :caption: Index
   :hidden:
   :glob:

   reference/*
